PrimaryKey class

Inheritance

Constructors

PrimaryKey({List<AlterDB> alters = const [], bool auto = true, String? name, int version = 1})
const

Properties

alters List<AlterDB>
finalinherited
auto bool
final
hashCode int
The hash code for this object.
no setterinherited
name String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited